==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/GitLabIdentityProviderBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class GitLabIdentityProviderBuilder extends io.fabric8.openshift.api.model.GitLabIdentityProviderFluentImpl<io.fabric8.openshift.api.model.GitLabIdentityProviderBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.GitLabIdentityProvider,io.fabric8.openshift.api.model.GitLabIdentityProviderBuilder>{
  public GitLabIdentityProviderBuilder() {
    this(false);
  }
  public GitLabIdentityProviderBuilder(java.lang.Boolean validationEnabled) {
    this(new GitLabIdentityProvider(), validationEnabled);
  }
  public GitLabIdentityProviderBuilder(io.fabric8.openshift.api.model.GitLabIdentityProviderFluent<?> fluent) {
    this(fluent, false);
  }
  public GitLabIdentityProviderBuilder(io.fabric8.openshift.api.model.GitLabIdentityProviderFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new GitLabIdentityProvider(), validationEnabled);
  }
  public GitLabIdentityProviderBuilder(io.fabric8.openshift.api.model.GitLabIdentityProviderFluent<?> fluent,io.fabric8.openshift.api.model.GitLabIdentityProvider instance) {
    this(fluent, instance, false);
  }
  public GitLabIdentityProviderBuilder(io.fabric8.openshift.api.model.GitLabIdentityProviderFluent<?> fluent,io.fabric8.openshift.api.model.GitLabIdentityProvider instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCa(instance.getCa()); 
    fluent.withClientID(instance.getClientID()); 
    fluent.withClientSecret(instance.getClientSecret()); 
    fluent.withUrl(instance.getUrl()); 
    this.validationEnabled = validationEnabled; 
  }
  public GitLabIdentityProviderBuilder(io.fabric8.openshift.api.model.GitLabIdentityProvider instance) {
    this(instance,false);
  }
  public GitLabIdentityProviderBuilder(io.fabric8.openshift.api.model.GitLabIdentityProvider instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withCa(instance.getCa()); 
    this.withClientID(instance.getClientID()); 
    this.withClientSecret(instance.getClientSecret()); 
    this.withUrl(instance.getUrl()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.GitLabIdentityProviderFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.GitLabIdentityProvider build() {
    GitLabIdentityProvider buildable = new GitLabIdentityProvider(fluent.getCa(),fluent.getClientID(),fluent.getClientSecret(),fluent.getUrl());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    GitLabIdentityProviderBuilder that = (GitLabIdentityProviderBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.12.0-sources.jar: io/fabric8/openshift/api/model/GitLabIdentityProviderBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class GitLabIdentityProviderBuilder extends io.fabric8.openshift.api.model.GitLabIdentityProviderFluentImpl<io.fabric8.openshift.api.model.GitLabIdentityProviderBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.GitLabIdentityProvider,io.fabric8.openshift.api.model.GitLabIdentityProviderBuilder>{
  public GitLabIdentityProviderBuilder() {
    this(false);
  }
  public GitLabIdentityProviderBuilder(java.lang.Boolean validationEnabled) {
    this(new GitLabIdentityProvider(), validationEnabled);
  }
  public GitLabIdentityProviderBuilder(io.fabric8.openshift.api.model.GitLabIdentityProviderFluent<?> fluent) {
    this(fluent, false);
  }
  public GitLabIdentityProviderBuilder(io.fabric8.openshift.api.model.GitLabIdentityProviderFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new GitLabIdentityProvider(), validationEnabled);
  }
  public GitLabIdentityProviderBuilder(io.fabric8.openshift.api.model.GitLabIdentityProviderFluent<?> fluent,io.fabric8.openshift.api.model.GitLabIdentityProvider instance) {
    this(fluent, instance, false);
  }
  public GitLabIdentityProviderBuilder(io.fabric8.openshift.api.model.GitLabIdentityProviderFluent<?> fluent,io.fabric8.openshift.api.model.GitLabIdentityProvider instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCa(instance.getCa()); 
    fluent.withClientID(instance.getClientID()); 
    fluent.withClientSecret(instance.getClientSecret()); 
    fluent.withUrl(instance.getUrl()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public GitLabIdentityProviderBuilder(io.fabric8.openshift.api.model.GitLabIdentityProvider instance) {
    this(instance,false);
  }
  public GitLabIdentityProviderBuilder(io.fabric8.openshift.api.model.GitLabIdentityProvider instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withCa(instance.getCa()); 
    this.withClientID(instance.getClientID()); 
    this.withClientSecret(instance.getClientSecret()); 
    this.withUrl(instance.getUrl()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.GitLabIdentityProviderFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.GitLabIdentityProvider build() {
    GitLabIdentityProvider buildable = new GitLabIdentityProvider(fluent.getCa(),fluent.getClientID(),fluent.getClientSecret(),fluent.getUrl());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    GitLabIdentityProviderBuilder that = (GitLabIdentityProviderBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
